@@ -10,16 +10,16 @@
  *          Gustavo Giráldez <gustavo.giraldez@gmx.net>
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
+ *  it under the terms of the GNU Library General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Library General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
@@ -145,6 +145,7 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 {
 	GObjectClass        *object_class;
 	GtkTextBufferClass  *tb_class;
+	GType                param_types[2];
 
 	object_class 	= G_OBJECT_CLASS (klass);
 	tb_class	= GTK_TEXT_BUFFER_CLASS (klass);
@@ -154,9 +155,6 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	object_class->get_property = gtk_source_buffer_get_property;
 	object_class->set_property = gtk_source_buffer_set_property;
 
-	klass->highlight_updated = NULL;
-	klass->marker_updated    = NULL;
-
 	/* Do not set these signals handlers directly on the parent_class since
 	 * that will cause problems (a loop). */
 	tb_class->insert_text 	= gtk_source_buffer_real_insert_text;
@@ -233,28 +231,28 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 							      GTK_TYPE_SOURCE_STYLE_SCHEME,
 							      G_PARAM_READWRITE));
 
+	param_types[0] = GTK_TYPE_TEXT_ITER | G_SIGNAL_TYPE_STATIC_SCOPE;
+	param_types[1] = GTK_TYPE_TEXT_ITER | G_SIGNAL_TYPE_STATIC_SCOPE;
+
 	buffer_signals[HIGHLIGHT_UPDATED] =
-	    g_signal_new ("highlight_updated",
-			  G_OBJECT_CLASS_TYPE (object_class),
-			  G_SIGNAL_RUN_LAST,
-			  G_STRUCT_OFFSET (GtkSourceBufferClass, highlight_updated),
-			  NULL, NULL,
-			  _gtksourceview_marshal_VOID__BOXED_BOXED,
-			  G_TYPE_NONE,
-			  2,
-			  GTK_TYPE_TEXT_ITER | G_SIGNAL_TYPE_STATIC_SCOPE,
-			  GTK_TYPE_TEXT_ITER | G_SIGNAL_TYPE_STATIC_SCOPE);
+	    g_signal_newv ("highlight_updated",
+			   G_OBJECT_CLASS_TYPE (object_class),
+			   G_SIGNAL_RUN_LAST,
+			   NULL,
+			   NULL, NULL,
+			   _gtksourceview_marshal_VOID__BOXED_BOXED,
+			   G_TYPE_NONE,
+			   2, param_types);
 
 	buffer_signals[MARKER_UPDATED] =
-	    g_signal_new ("marker_updated",
-			  G_OBJECT_CLASS_TYPE (object_class),
-			  G_SIGNAL_RUN_LAST,
-			  G_STRUCT_OFFSET (GtkSourceBufferClass, marker_updated),
-			  NULL, NULL,
-			  _gtksourceview_marshal_VOID__BOXED,
-			  G_TYPE_NONE,
-			  1,
-			  GTK_TYPE_TEXT_ITER | G_SIGNAL_TYPE_STATIC_SCOPE);
+	    g_signal_newv ("marker_updated",
+			   G_OBJECT_CLASS_TYPE (object_class),
+			   G_SIGNAL_RUN_LAST,
+			   NULL,
+			   NULL, NULL,
+			   _gtksourceview_marshal_VOID__BOXED,
+			   G_TYPE_NONE,
+			   1, param_types);
 
 	g_type_class_add_private (object_class, sizeof(GtkSourceBufferPrivate));
 }
@@ -1071,11 +1069,11 @@ update_bracket_match_style (GtkSourceBuffer *buffer)
 	if (buffer->priv->bracket_match_tag != NULL)
 	{
 		GtkSourceStyle *style = NULL;
+
 		if (buffer->priv->style_scheme)
 			style = gtk_source_style_scheme_get_matching_brackets_style (buffer->priv->style_scheme);
+
 		_gtk_source_style_apply (style, buffer->priv->bracket_match_tag);
-		if (style != NULL)
-			g_object_unref (style);
 	}
 }
 
@@ -1102,21 +1100,14 @@ gtk_source_buffer_get_highlight (GtkSourceBuffer *buffer)
  * @highlight: %TRUE if you want to activate highlighting.
  *
  * Controls whether text is highlighted in the buffer.  If @highlight
- * is %TRUE, the text will be highlighted according to the patterns
- * installed in the buffer (either set with
- * gtk_source_buffer_set_language() or by adding individual
- * #GtkSourceTag tags to the buffer's tag table).  Otherwise, any
- * current highlighted text will be restored to the default buffer
- * style.
+ * is %TRUE, the text will be highlighted according to the syntax
+ * highlighting specification installed in the buffer with
+ * gtk_source_buffer_set_language(). Otherwise, any current highlighted
+ * text will be restored to the default buffer style.
  *
  * Tags not of #GtkSourceTag type will not be removed by this option,
  * and normal #GtkTextTag priority settings apply when highlighting is
  * enabled.
- *
- * If not using a #GtkSourceLanguage for setting the highlighting
- * patterns in the buffer, it is recommended for performance reasons
- * that you add all the #GtkSourceTag tags with highlighting disabled
- * and enable it when finished.
  **/
 void
 gtk_source_buffer_set_highlight (GtkSourceBuffer *buffer,
