@@ -9,16 +9,16 @@
  *  Copyright (C) 2003 - Paolo Maggi, Gustavo Giráldez
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
+ *  it under the terms of the GNU Library General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Library General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
@@ -55,18 +55,13 @@ struct _GtkSourceBufferClass
 {
 	GtkTextBufferClass parent_class;
 
-	/* views connect to this signal */
-	void (* highlight_updated)      (GtkSourceBuffer *buffer,
-					 GtkTextIter     *start,
-					 GtkTextIter     *end);
-	void (* marker_updated)         (GtkSourceBuffer *buffer,
-					 GtkTextIter     *where);
-
 	/* Padding for future expansion */
 	void (*_gtk_source_reserved1) (void);
 	void (*_gtk_source_reserved2) (void);
 	void (*_gtk_source_reserved3) (void);
 	void (*_gtk_source_reserved4) (void);
+	void (*_gtk_source_reserved5) (void);
+	void (*_gtk_source_reserved6) (void);
 };
 
 GType           	 gtk_source_buffer_get_type 		(void) G_GNUC_CONST;
