@@ -104,8 +104,9 @@ struct _GtkSourceViewPrivate
 	gboolean	 indent_on_tab;
 	guint		 margin;
 	gint             cached_margin_width;
-	GtkSourceViewSmartHomeEndType smart_home_end;
+	GtkSourceSmartHomeEndType smart_home_end;
 
+	gboolean	 style_scheme_applied;
 	GtkSourceStyleScheme *style_scheme;
 	GdkGC		*current_line_gc;
 	GHashTable 	*pixmap_cache;
@@ -299,8 +300,8 @@ gtk_source_view_class_init (GtkSourceViewClass *klass)
 							    _("HOME and END keys move to first/last "
 							      "non whitespace characters on line before going "
 							      "to the start/end of the line"),
-							    GTK_TYPE_SOURCE_VIEW_SMART_HOME_END_TYPE,
-							    GTKSOURCEVIEW_SMART_HOME_END_DISABLED,
+							    GTK_TYPE_SOURCE_SMART_HOME_END_TYPE,
+							    GTK_SOURCE_SMART_HOME_END_DISABLED,
 							    G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
@@ -609,7 +610,7 @@ gtk_source_view_init (GtkSourceView *view)
 	view->priv->margin = DEFAULT_MARGIN;
 	view->priv->cached_margin_width = -1;
 	view->priv->indent_on_tab = TRUE;
-	view->priv->smart_home_end = GTKSOURCEVIEW_SMART_HOME_END_DISABLED;
+	view->priv->smart_home_end = GTK_SOURCE_SMART_HOME_END_DISABLED;
 
 	view->priv->pixmap_cache = g_hash_table_new_full (g_str_hash, g_str_equal,
 							  (GDestroyNotify) g_free,
@@ -1006,7 +1007,7 @@ gtk_source_view_move_cursor (GtkTextView    *text_view,
 
 		switch (source_view->priv->smart_home_end) {
 
-		case GTKSOURCEVIEW_SMART_HOME_END_BEFORE:
+		case GTK_SOURCE_SMART_HOME_END_BEFORE:
 			if (!gtk_text_iter_equal (&cur, &iter) ||
 			    gtk_text_iter_starts_line (&cur))
 			{
@@ -1015,7 +1016,7 @@ gtk_source_view_move_cursor (GtkTextView    *text_view,
 			}
 			break;
 
-		case GTKSOURCEVIEW_SMART_HOME_END_AFTER:
+		case GTK_SOURCE_SMART_HOME_END_AFTER:
 			if (gtk_text_iter_starts_line (&cur))
 			{
 				do_cursor_move (text_view, &cur, &iter, extend_selection);
@@ -1023,7 +1024,7 @@ gtk_source_view_move_cursor (GtkTextView    *text_view,
 			}
 			break;
 
-		case GTKSOURCEVIEW_SMART_HOME_END_ALWAYS:
+		case GTK_SOURCE_SMART_HOME_END_ALWAYS:
 			do_cursor_move (text_view, &cur, &iter, extend_selection);
 			return;
 
@@ -1037,7 +1038,7 @@ gtk_source_view_move_cursor (GtkTextView    *text_view,
 
 		switch (source_view->priv->smart_home_end) {
 
-		case GTKSOURCEVIEW_SMART_HOME_END_BEFORE:
+		case GTK_SOURCE_SMART_HOME_END_BEFORE:
 			if (!gtk_text_iter_equal (&cur, &iter) ||
 			    gtk_text_iter_ends_line (&cur))
 			{
@@ -1046,7 +1047,7 @@ gtk_source_view_move_cursor (GtkTextView    *text_view,
 			}
 			break;
 
-		case GTKSOURCEVIEW_SMART_HOME_END_AFTER:
+		case GTK_SOURCE_SMART_HOME_END_AFTER:
 			if (gtk_text_iter_ends_line (&cur))
 			{
 				do_cursor_move (text_view, &cur, &iter, extend_selection);
@@ -1054,7 +1055,7 @@ gtk_source_view_move_cursor (GtkTextView    *text_view,
 			}
 			break;
 
-		case GTKSOURCEVIEW_SMART_HOME_END_ALWAYS:
+		case GTK_SOURCE_SMART_HOME_END_ALWAYS:
 			do_cursor_move (text_view, &cur, &iter, extend_selection);
 			return;
 
@@ -2800,14 +2801,14 @@ gtk_source_view_set_margin (GtkSourceView *view, guint margin)
 /**
  * gtk_source_view_set_smart_home_end:
  * @view: a #GtkSourceView.
- * @smart_he: the desired behavior among #GtkSourceViewSmartHomeEndType
+ * @smart_he: the desired behavior among #GtkSourceSmartHomeEndType
  *
  * Set the desired movement of the cursor when HOME and END keys
  * are pressed.
  **/
 void
-gtk_source_view_set_smart_home_end (GtkSourceView                 *view,
-				    GtkSourceViewSmartHomeEndType  smart_he)
+gtk_source_view_set_smart_home_end (GtkSourceView             *view,
+				    GtkSourceSmartHomeEndType  smart_he)
 {
 	g_return_if_fail (GTK_IS_SOURCE_VIEW (view));
 
@@ -2823,10 +2824,10 @@ gtk_source_view_set_smart_home_end (GtkSourceView                 *view,
  * gtk_source_view_get_smart_home_end:
  * @view: a #GtkSourceView.
  *
- * Returns a #GtkSourceViewSmartHomeEndTypeend value specifying
+ * Returns a #GtkSourceSmartHomeEndTypeend value specifying
  * how the cursor will move when HOME and END keys are pressed.
  **/
-GtkSourceViewSmartHomeEndType
+GtkSourceSmartHomeEndType
 gtk_source_view_get_smart_home_end (GtkSourceView *view)
 {
 	g_return_val_if_fail (GTK_IS_SOURCE_VIEW (view), FALSE);
@@ -2897,9 +2898,17 @@ update_current_line_gc (GtkSourceView *view)
 static void
 gtk_source_view_realize (GtkWidget *widget)
 {
+	GtkSourceView *view = GTK_SOURCE_VIEW (widget);
+
 	GTK_WIDGET_CLASS (gtk_source_view_parent_class)->realize (widget);
 
-	update_current_line_gc (GTK_SOURCE_VIEW (widget));
+	if (view->priv->style_scheme != NULL && !view->priv->style_scheme_applied)
+	{
+		_gtk_source_style_scheme_apply (view->priv->style_scheme, widget);
+		view->priv->style_scheme_applied = TRUE;
+	}
+
+	update_current_line_gc (view);
 }
 
 static void
@@ -2934,7 +2943,14 @@ gtk_source_view_update_style_scheme (GtkSourceView *view)
 		view->priv->style_scheme = new_scheme;
 		if (new_scheme)
 			g_object_ref (new_scheme);
-		_gtk_source_style_scheme_apply (new_scheme, GTK_WIDGET (view));
-		update_current_line_gc (view);
+
+		if (GTK_WIDGET_REALIZED (view))
+		{
+			_gtk_source_style_scheme_apply (new_scheme, GTK_WIDGET (view));
+			update_current_line_gc (view);
+			view->priv->style_scheme_applied = TRUE;
+		}
+		else
+			view->priv->style_scheme_applied = FALSE;
 	}
 }
